"""Custom Exceptions.
"""


class IrregularURLException(Exception):
    pass


class InvalidPatternException(Exception):
    pass


class InvalidCharException(Exception):
    pass
